@@ -4,9 +4,7 @@ import time
 import inspect
 import logging
 import importlib
-import pyinotify
 import trimesh
-import numpy as np
 from decimal import Decimal
 from subprocess import Popen
 from solid2 import (scad_render, import_scad, import_stl,
@@ -25,6 +23,11 @@ def _build_uniq_id(args, kwargs):
     return ','.join(str(a) for a in all_args)
 
 class AbstractBaseNode:
+    """A mechanical project in solid-node is represented by a
+    tree, and this is the abstract base class for all nodes.
+    Above this class, there are two other base classes:
+    LeafNode and InternalNode.
+    """
 
     fn = None
 
